import React, { useEffect, useState } from "react";
import styled from "styled-components";
import ms from "pretty-ms";
import { useRoundSeconds, dispatch } from "../../../domain/gameStore";

const TimerSpan = styled.span`
  padding: 1px;
  display: inline;
`

const TimedOut = styled(TimerSpan)`
  color: red;
`

const useRoundTimer = onTimeout => {
  const remaining = useRoundSeconds();
  useEffect(() => {
    if (remaining > 0) {
      const timeout = setTimeout(() => { dispatch.setRoundSeconds(remaining - 1); }, 1000);
      return () => clearTimeout(timeout);
    }
  }, [remaining]);
  const [called, setCalled] = useState(false);
  useEffect(() => {
    if (!called && remaining <= 0) {
      onTimeout();
      setCalled(true);
    }
  }, [onTimeout, remaining, called]);
  return remaining;
}

export default ({ onTimeout }) => {
  const remaining = useRoundTimer(onTimeout);
  return (
    remaining > 0
      ? <TimerSpan>Time: {ms(remaining * 1000)}</TimerSpan>
      : <TimedOut>Time's up!</TimedOut>
  );
}
